@@ -1,9 +1,16 @@
+from __future__ import annotations
+
+import inspect
+import sys
 from copy import deepcopy
 from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
-from pydantic import BaseModel
+if sys.version_info[:2] < (3, 8):
+    from typing_extensions import Literal
+else:
+    from typing import Literal
 
-from indexpy.types import Literal
+from pydantic import BaseModel
 
 from .types import UploadFile
 
@@ -12,24 +19,24 @@ def schema_parameter(
     m: Optional[Type[BaseModel]],
     position: Literal["path", "query", "header", "cookie"],
 ) -> List[Dict[str, Any]]:
-    result = []
 
-    if m is not None:
-        _schemas = deepcopy(m.schema())
-        properties: Dict[str, Any] = _schemas["properties"]
-        required = _schemas.get("required", ())
+    if m is None:
+        return []
 
-        for name, schema in properties.items():  # type: str, Dict[str, str]
-            result.append(
-                {
-                    "in": position,
-                    "name": name,
-                    "description": schema.pop("description", ""),
-                    "required": name in required,  # type: ignore
-                    "schema": schema,
-                }
-            )
-    return result
+    _schemas = deepcopy(m.schema())
+    properties: Dict[str, Any] = _schemas["properties"]
+    required = _schemas.get("required", ())
+
+    return [
+        {
+            "in": position,
+            "name": name,
+            "description": schema.pop("description", ""),
+            "required": name in required,  # type: ignore
+            "schema": schema,
+        }
+        for name, schema in properties.items()
+    ]
 
 
 def schema_request_body(body: Type[BaseModel] = None) -> Tuple[Optional[Dict], Dict]:
@@ -41,7 +48,7 @@ def schema_request_body(body: Type[BaseModel] = None) -> Tuple[Optional[Dict], D
     content_type = "application/json"
 
     for field in body.__fields__.values():
-        if issubclass(field.type_, UploadFile):
+        if inspect.isclass(field.type_) and issubclass(field.type_, UploadFile):
             content_type = "multipart/form-data"
 
     return {
